---
jupytext:
  formats: ipynb,md:myst
  text_representation:
    extension: .md
    format_name: myst
    format_version: 0.13
    jupytext_version: 1.14.1
kernelspec:
  display_name: Python 3 (ipykernel)
  language: python
  name: python3
---

# 20 Newsgoups: Intro

Aufgaben, spezifisch für dsci-txt:

* klassischer Datensatz: https://scikit-learn.org/0.19/datasets/twenty_newsgroups.html

aktuell 2023:
https://scikit-learn.org/stable/modules/generated/sklearn.datasets.fetch_20newsgroups.html#sklearn.datasets.fetch_20newsgroups

```{code-cell} ipython3
from sklearn.datasets import fetch_20newsgroups
cats = ['alt.atheism', 'sci.space']
newsgroups_train = fetch_20newsgroups(subset='train', 
    categories=cats,
    shuffle=True, 
    random_state=42,
    remove = ('headers', 'footers', 'quotes')  # hinzugefügt JB
                                     )                                  
newsgroups_train.target_names
```

```{code-cell} ipython3
type(newsgroups_train)
```

Bunch: <https://scikit-learn.org/stable/modules/generated/sklearn.utils.Bunch.html#sklearn.utils.Bunch>

+++

Bunch is just like dictionary but it supports attribute type access. This is the main difference between bunch and dict: In a Bunch, you can access the attributes using dot notations. In a dict this is not possible. <https://stackoverflow.com/questions/56286221/what-is-the-difference-between-bunch-and-dictionary-type-in-python>

```{code-cell} ipython3
newsgroups_train.keys()
```

```{code-cell} ipython3
newsgroups_train["target"]
```

```{code-cell} ipython3
newsgroups_train.target_names # dot-Notation statt newsgroups_train['target_names']
```

```{code-cell} ipython3
type(newsgroups_train.filenames)
```

```{code-cell} ipython3
newsgroups_train.filenames.shape
```

```{code-cell} ipython3
len(newsgroups_train.filenames) 
```

`newsgroups_train.data` ist eine Liste von Strings:

```{code-cell} ipython3
type(newsgroups_train.data)
```

```{code-cell} ipython3
# newsgroups_train.data
```

```{code-cell} ipython3
newsgroups_train.data[:2]
```

`newsgroups_train.target` ist eine Liste von Zahlen vom Typ Integer. Für jeden String in der Liste `newsgroups_train.data` ist das Target angeben:

```{code-cell} ipython3
newsgroups_train.target
```

```{code-cell} ipython3
print(newsgroups_train.target.shape)
```

```{code-cell} ipython3

```
